@@ -19,10 +19,11 @@ else:
     from typing_extensions import Literal
 
 
-__all__ = ("AlternateContactTypeType", "ServiceName")
+__all__ = ("AlternateContactTypeType", "AccountServiceName", "ServiceName", "ResourceServiceName")
 
 
 AlternateContactTypeType = Literal["BILLING", "OPERATIONS", "SECURITY"]
+AccountServiceName = Literal["account"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -54,6 +55,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -176,6 +178,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -324,3 +327,15 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
